@@ -14,7 +14,7 @@ use SHARYANTO::Package::Util qw(package_exists);
 use URI;
 use UUID::Random;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.36'; # VERSION
 
 our $re_mod = qr/\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_][A-Za-z_0-9]*)*\z/;
 
@@ -379,8 +379,9 @@ sub action_call {
     my ($code, $meta) = @{$res->[2]};
     my %args = %{ $req->{args} // {} };
 
+    my $risub = risub($meta);
+
     if ($req->{dry_run}) {
-        my $risub = risub($meta);
         return [412, "Function does not support dry run"]
             unless $risub->can_dry_run;
         if ($risub->feature('dry_run')) {
@@ -393,6 +394,11 @@ sub action_call {
         }
     }
 
+    if ($risub->feature('progress')) {
+        require Progress::Any;
+        $args{-progress} = Progress::Any->get_indicator();
+    }
+
     if ($tm) {
         $res = $tm->action(
             f => "$req->{-module}::$req->{-leaf}", args=>\%args,
@@ -733,7 +739,7 @@ Perinci::Access::InProcess - Use Rinci access protocol (Riap) to access Perl cod
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -803,7 +809,8 @@ already accessible from Perl like functions and metadata (in C<%SPEC>). Indeed,
 if you do not need Riap, you can access your module just like any normal Perl
 module.
 
-But Perinci::Access::InProcess offers several benefits:
+But Perinci::Access::InProcess (called B<periai> for short) offers several
+benefits:
 
 =over 4
 
@@ -841,6 +848,20 @@ The default accessor class is L<Perinci::MetaAccessor::Default>. Alternatively,
 you can simply devise your own system to retrieve metadata which you can put in
 C<%SPEC> at the end.
 
+=head2 Progress indicator
+
+periai can also display progress indicator for function that does progress
+updating. Function expresses that it does progress updating through the
+C<features> property in its metadata:
+
+ features => {
+     progress => 1,
+     ...
+ }
+
+periai will then pass a special argument C<-progress> containing
+L<Progress::Any> object.
+
 =for Pod::Coverage ^actionmeta_.+ ^action_.+
 
 =head1 METHODS
